From f5f4be88f020eca02a59122758518fe978c5e30d Mon Sep 17 00:00:00 2001
From: Michael Telatynski <7t3chguy@gmail.com>
Date: Mon, 12 Jul 2021 08:34:26 +0100
Subject: [PATCH] Update tests to expect LinkPreviewGroup behaviour
---
.../views/messages/TextualBody-test.js | 19 +++++++++----------
1 file changed, 9 insertions(+), 10 deletions(-)
diff --git a/test/components/views/messages/TextualBody-test.js b/test/components/views/messages/TextualBody-test.js
index c6a3f3c779..fd11a9d46b 100644
--- a/test/components/views/messages/TextualBody-test.js
+++ b/test/components/views/messages/TextualBody-test.js
@@ -22,8 +22,10 @@ import sdk from "../../../skinned-sdk";
import { mkEvent, mkStubRoom } from "../../../test-utils";
import { MatrixClientPeg } from "../../../../src/MatrixClientPeg";
import * as languageHandler from "../../../../src/languageHandler";
+import * as TestUtils from "../../../test-utils";
-const TextualBody = sdk.getComponent("views.messages.TextualBody");
+const _TextualBody = sdk.getComponent("views.messages.TextualBody");
+const TextualBody = TestUtils.wrapInMatrixClientContext(_TextualBody);
configure({ adapter: new Adapter() });
@@ -305,10 +307,9 @@ describe("", () => {
const wrapper = mount( {}} />);
expect(wrapper.text()).toBe(ev.getContent().body);
- let widgets = wrapper.find("LinkPreviewWidget");
- // at this point we should have exactly one widget
- expect(widgets.length).toBe(1);
- expect(widgets.at(0).prop("link")).toBe("https://matrix.org/");
+ let widgets = wrapper.find("LinkPreviewGroup");
+ // at this point we should have exactly one link
+ expect(widgets.at(0).prop("links")).toEqual(["https://matrix.org/"]);
// simulate an event edit and check the transition from the old URL preview to the new one
const ev2 = mkEvent({
@@ -333,11 +334,9 @@ describe("", () => {
// XXX: this is to give TextualBody enough time for state to settle
wrapper.setState({}, () => {
- widgets = wrapper.find("LinkPreviewWidget");
- // at this point we should have exactly two widgets (not the matrix.org one anymore)
- expect(widgets.length).toBe(2);
- expect(widgets.at(0).prop("link")).toBe("https://vector.im/");
- expect(widgets.at(1).prop("link")).toBe("https://riot.im/");
+ widgets = wrapper.find("LinkPreviewGroup");
+ // at this point we should have exactly two links (not the matrix.org one anymore)
+ expect(widgets.at(0).prop("links")).toEqual(["https://vector.im/", "https://riot.im/"]);
});
});
});